@@ -9,7 +9,7 @@ use Data::Printer alias => 'pdump';
 use SQL::Abstract::Complete;
 use MySQL::Util::Lite;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 =head1 SYNOPSIS
 
@@ -63,7 +63,8 @@ has __lite => (
 has _lite_ready => (
     is      => 'rw',
     isa     => 'Bool',
-    default => 0
+    default => 0,
+    init_arg => '_hide'
 );
 
 has _schema => (
@@ -94,6 +95,17 @@ has _prune_ddl => (
 # public methods
 ##############################################################################
 
+method begin_work(){
+    $self->dbh->begin_work;
+}
+
+method rollback(){
+    $self->dbh->rollback;   
+}
+
+method commit(){
+    $self->dbh->commit;   
+}
 
 =head1 SUBROUTINES/METHODS
 
@@ -377,7 +389,7 @@ method _build_schema_name {
 method _build__lite {
 	
 	my $schema = $self->schema_name;
-	my $clone = $self->dbh->clone;
+	my $clone = $self->dbh->clone( { InactiveDestroy => 1, ReadOnly => 1 } );
 	$clone->do("use $schema");
 	
 	$self->_lite_ready(1);
@@ -385,18 +397,6 @@ method _build__lite {
 	return MySQL::Util::Lite->new( dbh => $clone, span => 1 );
 }
 
-sub DESTROY {
-    my $self = shift;
-    
-    #
-    # Should disconnect our dbh clone if we created one.
-    # Otherwise, we might get annoying warning messages
-    #
-    if( $self->_lite_ready ){
-        $self->__lite->dbh->disconnect()   
-    }
-}
-
 1;
 
 =head1 AUTHOR
